"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const types_1 = require("./types");
const hubSteps_1 = tslib_1.__importDefault(require("./steps/hubSteps"));
const oracleSteps_1 = tslib_1.__importDefault(require("./steps/oracleSteps"));
const participantSteps_1 = tslib_1.__importDefault(require("./steps/participantSteps"));
const partySteps_1 = tslib_1.__importDefault(require("./steps/partySteps"));
function getCollections(bootstrapType, config) {
    if (bootstrapType === types_1.BootstrapType.ALL) {
        return [
            hubSteps_1.default(config),
            oracleSteps_1.default(config),
            ...config.participants.map(p => participantSteps_1.default(p)(config)),
            ...config.participants
                .filter(p => p.type === types_1.ParticipantType.DFSP || p.type === types_1.ParticipantType.DFSP_SUPPORTING_PISP)
                // we cast here because TS isn't smart enough to figure out the types after a filter
                .map(p => partySteps_1.default(p)(config)),
        ];
    }
    switch (bootstrapType) {
        case types_1.BootstrapType.HUB:
            return [
                hubSteps_1.default(config),
                oracleSteps_1.default(config),
            ];
        case types_1.BootstrapType.PARTICIPANTS:
            return [...config.participants.map(p => participantSteps_1.default(p)(config))];
        case types_1.BootstrapType.PARTIES:
            return [...config.participants
                    .filter(p => p.type === types_1.ParticipantType.DFSP || p.type === types_1.ParticipantType.DFSP_SUPPORTING_PISP)
                    // we cast here because TS isn't smart enough to figure out the types after a filter
                    .map(p => partySteps_1.default(p)(config)),
            ];
    }
}
exports.default = getCollections;
//# sourceMappingURL=collections.js.map