"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const axios_1 = tslib_1.__importDefault(require("axios"));
const Logger = require('@mojaloop/central-services-logger');
// TODO: make this configurable
// Timeout in ms
const timeout = 15 * 1000;
class Requests {
    static async postHubAccount(host, request) {
        const url = `${host}/participants/Hub/accounts`;
        Logger.debug('postHubAccount - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postSettlementModel(host, request) {
        const url = `${host}/settlementModels`;
        Logger.debug('postSettlementModel - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postHubEndpoints(host, request) {
        const url = `${host}/participants/Hub/endpoints`;
        Logger.debug('postHubEndpoints - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postOracles(host, request) {
        const url = `${host}/oracles`;
        Logger.debug('postOracles - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
                Date: (new Date()).toISOString()
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postParticipants(host, request) {
        const url = `${host}/participants`;
        Logger.debug('postParticipants - ' + url);
        const options = {
            method: 'post',
            timeout,
            headers: {
                'Content-Type': 'application/json',
            },
            url,
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postParticipantsPositionAndLimits(host, request) {
        const url = `${host}/participants/${request.participantId}/initialPositionAndLimits`;
        Logger.debug('postParticipantsPositionAndLimits - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async getParticipant(host, participantId) {
        const url = `${host}/participants/${participantId}`;
        Logger.debug('getParticipant - ' + url);
        const options = {
            method: 'get',
            timeout,
            url,
        };
        return this.executeRequest(options);
    }
    static async postAccount(host, request) {
        const url = `${host}/participants/${request.participantId}/accounts/${request.accountId}`;
        Logger.debug('postAccount - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postEndpoint(host, request) {
        const url = `${host}/participants/${request.participantId}/endpoints`;
        Logger.debug('postEndpoint - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postSimulatorParty(host, request) {
        const url = `${host}/repository/parties`;
        Logger.debug('postSimulatorParty - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Content-Type': 'application/json',
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async postALSParticipant(host, request) {
        const url = `${host}/participants/${request.idType}/${request.idValueOrSubType}` + (request.idValue ? `/${request.idValue}` : '');
        Logger.debug('postALSParticipant - ' + url);
        const options = {
            method: 'post',
            timeout,
            url,
            headers: {
                'Accept': 'application/vnd.interoperability.participants+json;version=1',
                'Content-Type': 'application/vnd.interoperability.participants+json;version=1.0',
                Date: (new Date()).toISOString(),
                ...request.headers
            },
            data: {
                ...request.body
            }
        };
        return this.executeRequest(options);
    }
    static async executeRequest(options) {
        try {
            Logger.silly('executeRequest');
            Logger.silly(JSON.stringify(options, null, 2));
            const result = await axios_1.default(options);
            return result;
        }
        catch (err) {
            if (err.response) {
                Logger.warn(`executeRequest failed with status: ${err.response.status}`);
                Logger.debug(JSON.stringify(err.response.data, null, 2));
                // TODO: better error handling
                throw new Error(`Status: ${err.response.status} Message: ${JSON.stringify(err.response.data)}`);
            }
            Logger.warn('Generic Error' + err.message);
            throw err;
        }
    }
}
exports.default = Requests;
//# sourceMappingURL=requests.js.map