import { AxiosResponse } from 'axios';
import * as SDKStandardComponents from '@mojaloop/sdk-standard-components';
import { Party } from 'types';
export declare type PostHubAccountRequest = {
    body: {
        type: 'HUB_MULTILATERAL_SETTLEMENT' | 'HUB_RECONCILIATION';
        currency: SDKStandardComponents.TCurrency;
    };
};
export declare type PostSettlementModelRequest = {
    body: {
        name: string;
        settlementGranularity: string;
        settlementInterchange: string;
        settlementDelay: string;
        requireLiquidityCheck: boolean;
        ledgerAccountType: string;
        autoPositionReset: boolean;
        currency: SDKStandardComponents.TCurrency;
        settlementAccountType: string;
    };
};
export declare type PostHubEndpointRequest = {
    body: {
        type: 'SETTLEMENT_TRANSFER_POSITION_CHANGE_EMAIL' | 'NET_DEBIT_CAP_ADJUSTMENT_EMAIL' | 'NET_DEBIT_CAP_THRESHOLD_BREACH_EMAIL';
        value: string;
    };
};
export declare type PostOraclesRequest = {
    body: {
        oracleIdType: string;
        endpoint: {
            value: string;
            endpointType: string;
        };
        currency: SDKStandardComponents.TCurrency;
        isDefault: true;
    };
};
export declare type PostParticipantsRequest = {
    body: {
        name: string;
        currency: SDKStandardComponents.TCurrency;
    };
};
export declare type PostParticipantsPositionAndLimitsRequest = {
    participantId: string;
    body: {
        currency: SDKStandardComponents.TCurrency;
        limit: {
            type: string;
            value: number;
        };
        initialPosition: number;
    };
};
export declare type PostAccountRequest = {
    participantId: string;
    accountId: string;
    body: {
        transferId: string;
        externalReference: string;
        action: string;
        reason: string;
        amount: {
            amount: string;
            currency: SDKStandardComponents.TCurrency;
        };
    };
};
export declare type PostEndpointsRequest = {
    participantId: string;
    body: {
        type: string;
        value: string;
    };
};
export declare type PostSimulatorPartyRequest = {
    body: Party;
};
export declare type PostALSParticipantRequest = {
    headers: {
        'FSPIOP-Source': string;
    };
    idType: string;
    idValueOrSubType: string;
    idValue?: string;
    body: {
        fspId: string;
        currency: SDKStandardComponents.TCurrency;
    };
};
export declare type GetParticipantResponse = {
    name: string;
    created: string;
    isActive: number;
    accounts: Array<PartcipantAccount>;
};
export declare type PartcipantAccount = {
    id: number;
    ledgerAccountType: string;
    currency: SDKStandardComponents.TCurrency;
    isActive: number;
    createdDate: unknown;
    createdBy: unknown;
};
export default class Requests {
    static postHubAccount(host: string, request: PostHubAccountRequest): Promise<AxiosResponse<any>>;
    static postSettlementModel(host: string, request: PostSettlementModelRequest): Promise<AxiosResponse<any>>;
    static postHubEndpoints(host: string, request: PostHubEndpointRequest): Promise<AxiosResponse<any>>;
    static postOracles(host: string, request: PostOraclesRequest): Promise<AxiosResponse<any>>;
    static postParticipants(host: string, request: PostParticipantsRequest): Promise<AxiosResponse<any>>;
    static postParticipantsPositionAndLimits(host: string, request: PostParticipantsPositionAndLimitsRequest): Promise<AxiosResponse<any>>;
    static getParticipant(host: string, participantId: string): Promise<AxiosResponse<GetParticipantResponse>>;
    static postAccount(host: string, request: PostAccountRequest): Promise<AxiosResponse<any>>;
    static postEndpoint(host: string, request: PostEndpointsRequest): Promise<AxiosResponse<any>>;
    static postSimulatorParty(host: string, request: PostSimulatorPartyRequest): Promise<AxiosResponse<any>>;
    static postALSParticipant(host: string, request: PostALSParticipantRequest): Promise<AxiosResponse<any>>;
    private static executeRequest;
}
