"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.GenericSteps = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const runResult_1 = require("../runResult");
const Logger = require('@mojaloop/central-services-logger');
class GenericSteps {
    constructor(constConfig, globalConfig, stepGenerator) {
        this.id = constConfig.id;
        this.name = constConfig.name;
        this.description = constConfig.description;
        this.ignoreFailure = constConfig.ignoreFailure;
        this.steps = stepGenerator(globalConfig);
    }
    async run() {
        let warnings = [];
        let errors = [];
        for (const step of this.steps) {
            Logger.info("  - step:" + chalk_1.default.magenta(step.name));
            const result = await step.command();
            warnings = warnings.concat(result.warnings);
            if (result.type === runResult_1.RunResultType.FAILURE) {
                if (step.ignoreFailure) {
                    // add to warnings - we are ignoring the failure
                    warnings = warnings.concat(result.errors.map(e => `${step.name}: ${e.name}, ${e.message}`));
                }
                else {
                    // only add errors if we aren't ignoring failures
                    errors = errors.concat(result.errors);
                }
            }
        }
        if (errors.length > 0) {
            return runResult_1.Result.Failure(errors, warnings);
        }
        return runResult_1.Result.Success(warnings);
    }
}
exports.GenericSteps = GenericSteps;
//# sourceMappingURL=genericSteps.js.map