"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Logger = require('@mojaloop/central-services-logger');
const requests_1 = tslib_1.__importDefault(require("../requests"));
const utils_1 = require("../utils");
const genericSteps_1 = require("./genericSteps");
// Step Constant config
// This won't change dynamically
const constConfig = {
    id: 'oraclesteps',
    name: 'Oracle Steps',
    description: 'Seeds the initial oracle config',
    ignoreFailure: true,
};
// Define steps here
const stepGenerator = (config) => {
    const steps = [];
    config.currencies.forEach(currency => {
        config.oracles.forEach(oracleConfig => {
            steps.push({
                name: `create a ${oracleConfig.oracleIdType} oracle for currency: ${currency}`,
                // This command is not idempotent
                ignoreFailure: true,
                command: utils_1.wrapWithRunResult(() => requests_1.default.postOracles(config.urls.alsAdmin, {
                    body: {
                        oracleIdType: oracleConfig.oracleIdType,
                        endpoint: {
                            value: `${oracleConfig.endpoint}`,
                            endpointType: "URL"
                        },
                        currency,
                        // Hmm this might be a probalem...
                        isDefault: true
                    }
                }))
            });
        });
    });
    return steps;
};
const steps = (config) => new genericSteps_1.GenericSteps(constConfig, config, stepGenerator);
exports.default = steps;
//# sourceMappingURL=oracleSteps.js.map