"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const requests_1 = tslib_1.__importDefault(require("../requests"));
const utils_1 = require("../utils");
const genericSteps_1 = require("./genericSteps");
function makeStepsForParticipantAndParties(config, participant, currencies) {
    const steps = [];
    currencies.forEach(currency => {
        // For Each currency, 
        participant.parties.forEach(party => {
            // For each party
            // 1. Register at the ALS
            // 2. Create an entry in the Simulator
            const participantsEndpoint = config.urls.fspiop || config.urls.alsEndpoint;
            if (!participantsEndpoint) {
                throw new Error('Endpoint for `/participants not defined. You must set either `urls.fspiop` or `urls.alsEndpoint');
            }
            steps.push({
                name: `register with ALS: ${party.idType}/${party.idValue}, currency: ${currency}`,
                ignoreFailure: false,
                command: utils_1.wrapWithRunResult(() => requests_1.default.postALSParticipant(participantsEndpoint, {
                    headers: {
                        'FSPIOP-Source': participant.id
                    },
                    idType: party.idType,
                    idValueOrSubType: party.idValue,
                    body: {
                        fspId: participant.id,
                        currency
                    }
                }))
            });
            steps.push({
                name: `register with simulator ${party.idType}/${party.idValue}`,
                // Will fail if already exists - this will happen for subsequent requests
                // or if registering more than 1 currency
                ignoreFailure: true,
                command: utils_1.wrapWithRunResult(() => requests_1.default.postSimulatorParty(participant.simulatorAdminUrl, {
                    body: {
                        ...party
                    }
                }))
            });
        });
    });
    return steps;
}
function makePartySteps(participant) {
    const constConfig = {
        id: `parties_for_participant_${participant.id}`,
        name: `Parties Steps - ${participant.id}`,
        description: `Sets up parties for ${participant.id}`,
        ignoreFailure: false,
    };
    const stepGenerator = (config) => makeStepsForParticipantAndParties(config, participant, config.currencies);
    return (config) => new genericSteps_1.GenericSteps(constConfig, config, stepGenerator);
}
exports.default = makePartySteps;
//# sourceMappingURL=partySteps.js.map