"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const config_1 = require("../../src/config");
const utils_1 = require("./utils");
describe('config', () => {
    describe('formatAndValidateConfig', () => {
        it('throws if both currency and currencies is specified', () => {
            // Arrange
            const input = {
                currency: 'USD',
                currencies: ['AED'],
                urls: {
                    fspiop: 'example',
                    alsEndpoint: 'example',
                    alsAdmin: 'example',
                    centralLedgerAdmin: 'example',
                },
                applicationUrls: {
                    oracle: 'example'
                },
                oracles: [
                    { oracleIdType: "MSISDN", endpoint: "http://beta.moja-lab.live/api/admin/oracle-simulator" }
                ],
                participants: []
            };
            // Act
            try {
                config_1.formatAndValidateConfig(input);
                utils_1.shouldNotBeExecuted();
            }
            catch (err) {
                // Assert
                const message = err.message;
                expect(message).toMatch('Cannot specify both `currency` and `currencies`. Please use updated config');
            }
        });
        it('coerces old currency config into new format', () => {
            // Arrange
            const input = {
                currency: 'USD',
                currencies: [],
                urls: {
                    fspiop: 'example',
                    alsEndpoint: 'example',
                    alsAdmin: 'example',
                    centralLedgerAdmin: 'example',
                },
                applicationUrls: {
                    oracle: 'example'
                },
                oracles: [
                    { oracleIdType: "MSISDN", endpoint: "http://beta.moja-lab.live/api/admin/oracle-simulator" }
                ],
                participants: []
            };
            const expected = {
                currency: undefined,
                currencies: ['USD'],
                urls: {
                    fspiop: 'example',
                    alsEndpoint: 'example',
                    alsAdmin: 'example',
                    centralLedgerAdmin: 'example',
                },
                applicationUrls: {
                    oracle: 'example'
                },
                oracles: [
                    { oracleIdType: "MSISDN", endpoint: "http://beta.moja-lab.live/api/admin/oracle-simulator" }
                ],
                participants: []
            };
            // Act
            const result = config_1.formatAndValidateConfig(input);
            // Assert
            expect(result).toStrictEqual(expected);
        });
    });
});
//# sourceMappingURL=config.test.js.map